# OSV library
This is a set of helper utilities for the Open Source Vulnerabilities project.

This includes:
- Computing affected tags from input git ranges.
- Version normalization for indexing.
- Git repo helpers for vulnerability DB maintainence.

## Stability
This package is not yet stable, and APIs are subject to change.
